==================
wrongbutusefulsbi
==================

A brief description of the wrongbutusefulsbi package.

Getting Started
===============

Instructions on getting started with wrongbutusefulsbi will be added here.

Contribute
==========

- Issue Tracker: https://github.com/RyanJafefKelly/wrongbutusefulsbi/issues
- Source Code: https://github.com/RyanJafefKelly/wrongbutusefulsbi

Support
=======

If you are having issues, please let us know.
We have a mailing list located at: ryan@kiiii.com

License
=======

The project is licensed under the GPLv3 license.
